@@ -1,9 +1,10 @@
 #' Bayesian variable selection for the Poisson model
 #' 
 #' This function performs Bayesian variable selection for Poisson regression models 
-#' with spike and slab priors. A cluster-specific random intercept can be included in
-#' the model to account for within-cluster dependence with variance selection of
-#' the random intercept. For posterior inference, a MCMC sampling scheme is used
+#' via spike and slab priors. A cluster- (or observation-) specific 
+#' random intercept can be included in the model to account for within-cluster 
+#' dependence (or overdispersion) with variance selection of the random intercept. 
+#' For posterior inference, a MCMC sampling scheme is used
 #' which relies on data augmentation and involves only Gibbs sampling steps.
 #' 
 #' The method provides a Bayesian framework for variable selection in regression
@@ -29,7 +30,7 @@
 #' \code{bayesf}, Version 2.0 of Fruehwirth-Schnatter (2007) are used.  
 #' See Fruehwirth-Schnatter et al. (2009) for details.
 #' 
-#' For details concerning the sampling algorithm see Dvorzak and Wagner (online first version) 
+#' For details concerning the sampling algorithm, see Dvorzak and Wagner (2016) 
 #' and Wagner and Duller (2012). 
 #' 
 #' Details for the model specification (see arguments): 
@@ -43,11 +44,13 @@
 #'    the random intercept term (i.e., 0 = with variance selection (default), 1 = no 
 #'    variance selection); only used if a random intercept is includued in the model 
 #'    (see \code{ri}).} 
-#'    \item{\code{ri}}{logical. If \code{TRUE}, a cluster-specific 
+#'    \item{\code{ri}}{logical. If \code{TRUE}, a cluster- (or observation-) specific 
 #'    random intercept is included in the model; defaults to \code{FALSE}.} 
 #'    \item{\code{clusterID}}{a numeric vector of length equal to the number
 #'    of observations containing the cluster ID c = 1,...,C for each observation 
-#'    (required if \code{ri=TRUE}).} 
+#'    (required if \code{ri=TRUE}). Note that \code{seq_along(y)} specifies an
+#'    overdispersed Poisson model with observation-specific (normal) random intercept 
+#'    (see note).} 
 #'  }}
 #'  \item{\code{prior}}{\describe{\item{}{A list:}      
 #'    \item{\code{slab}}{distribution of the slab component, i.e. "\code{Student}" 
@@ -57,7 +60,7 @@
 #'    \item{\code{m0}}{prior mean for the intercept parameter; defaults to 0.} 
 #'    \item{\code{M0}}{prior variance for the intercept parameter; defaults to 100.} 
 #'    \item{\code{aj0}}{a vector of prior means for the regression effects 
-#'    (which is encoded in a normal distribution, see notes); defaults to vector of 
+#'    (which is encoded in a normal distribution, see note); defaults to vector of 
 #'    zeros.} 
 #'    \item{\code{V}}{variance of the slab; defaults to 5.} 
 #'    \item{\code{w}}{hyper-parameters of the Beta-prior for the mixture weight
@@ -101,41 +104,51 @@
 #'  \code{\link{print.pogit}}, \code{\link{summary.pogit}} and 
 #'  \code{\link{plot.pogit}}. 
 #' 
-#'  An object of class "\code{pogit}" is a list containing the following components: 
+#'  The returned object is a list containing the following elements: 
 #' 
 #'  \item{\code{samplesP}}{a named list containing the samples from the posterior
-#'    distribution of the parameters (see also \code{msave}): 
+#'    distribution of the parameters in the Poisson model 
+#'    (see also \code{msave}): 
 #'    \describe{
 #'    \item{\code{beta, thetaBeta}}{regression coefficients \eqn{\beta} and
 #'    \eqn{\theta_\beta}}
 #'    \item{\code{pdeltaBeta}}{P(\eqn{\delta_\beta}=1)}
 #'    \item{\code{psiBeta}}{scale parameter \eqn{\psi_\beta} of the slab component}
 #'    \item{\code{pgammaBeta}}{P(\eqn{\gamma_\beta}=1)}
-#'    \item{\code{bi}}{cluster-specific random intercept}
+#'    \item{\code{bi}}{cluster- (or observation-) specific random intercept}
 #'    }}
 #'  \item{\code{data}}{a list containing the data \code{y}, \code{offset} and \code{X}}
-#'  \item{\code{model.pois}}{see \code{model} arguments}
-#'  \item{\code{mcmc}}{see \code{mcmc} arguments}
-#'  \item{\code{prior.pois}}{see \code{prior} arguments}
+#'  \item{\code{model.pois}}{a list containing details on the model specification, 
+#'  see details for \code{model}}
+#'  \item{\code{mcmc}}{see details for \code{mcmc}}
+#'  \item{\code{prior.pois}}{see details for \code{prior}}
 #'  \item{\code{dur}}{a list containing the total runtime (\code{total}) 
 #'    and the runtime after burn-in (\code{durM}), in seconds}
 #'  \item{\code{BVS}}{see arguments}
-#'  \item{\code{start}}{see arguments}
+#'  \item{\code{start}}{a list containing starting values, see arguments}
 #'  \item{\code{family}}{"poisson"}
 #'  \item{\code{call}}{function call}
 #'  
 #'   
 #' @note If prior information on the regression parameters is available, this 
-#'   prior information is encoded in a normal distribution instead of the spike 
-#'   and slab prior (\code{BVS} is set to \code{FALSE}).
-#' @seealso \code{\link{pogitBvs}}
+#'   information is encoded in a normal distribution instead of the spike 
+#'   and slab prior (consequently, \code{BVS} is set to \code{FALSE}).
+#' @note This function can also be used to accommodate overdispersion in 
+#'   count data by specifying an observation-specific random intercept
+#'   (see details for \code{model}). The resulting model is an alternative 
+#'   to the negative binomial model, see \code{\link{negbinBvs}}. 
+#'   Variance selection of the random intercept may be useful to examine 
+#'   whether overdispersion is present in the data. 
 #'   
-#' @references Dvorzak, M. and Wagner, H. (online first version). Sparse Bayesian modelling
-#'  of underreported count data. \emph{Statistical Modelling}, 2015-06-18,
-#'  \url{http://dx.doi.org/10.1177/1471082x15588398}.
+#' @seealso \code{\link{pogitBvs}}, \code{\link{negbinBvs}}
+#' @keywords models
+#'  
+#' @references Dvorzak, M. and Wagner, H. (2016). Sparse Bayesian modelling
+#'  of underreported count data. \emph{Statistical Modelling}, \strong{16}(1),
+#'  24 - 46, \url{http://dx.doi.org/10.1177/1471082x15588398}.
 #' @references Fruehwirth-Schnatter, S. (2007). Matlab package \code{bayesf} 2.0
 #'   on \emph{Finite Mixture and Markov Switching Models}, Springer. 
-#'   URL <http://statmath.wu.ac.at/~fruehwirth/monographie/>.
+#'   \url{http://statmath.wu.ac.at/~fruehwirth/monographie/}.
 #' @references Fruehwirth-Schnatter, S., Fruehwirth, R., Held, L. and Rue, H. 
 #'   (2009). Improved auxiliary mixture sampling for hierarchical models of 
 #'   non-Gaussian data. \emph{Statistics and Computing}, \strong{19}, 479 - 492.
@@ -167,18 +180,29 @@
 #' print(m1)
 #' summary(m1)
 #' plot(m1, maxPlots = 4)
+#' plot(m1, burnin = FALSE, thin = FALSE, maxPlots = 4)
 #' plot(m1, type = "acf")
 #' 
 #' # MCMC sampling without BVS with specific MCMC and prior settings
 #' m2 <- poissonBvs(y = y, X = X, prior = list(slab = "Normal"), 
 #'                  mcmc = list(M = 6000, thin = 10), BVS = FALSE)
-#'
 #' print(m2)
 #' summary(m2, IAT = TRUE)
 #' plot(m2)
 #' # show traceplots disregarding thinning
 #' plot(m2, thin = FALSE)
 #' 
+#' # specification of an overdispersed Poisson model with observation-specific 
+#' # (normal) random intercept
+#' cID <- seq_along(y)
+#' m3  <- poissonBvs(y = y, X = X, model = list(ri = TRUE, clusterID = cID))
+#' 
+#' # print, summarize and plot results
+#' print(m3)
+#' summary(m3) 
+#' # note that variance selection of the random intercept indicates that 
+#' # overdispersion is not present in the data
+#' plot(m3, burnin = FALSE, thin = FALSE)
 #' 
 #' ## ------ (use simul_pois2) ------
 #' # load simulated data set 'simul_pois2'
@@ -187,26 +211,26 @@
 #' X <- as.matrix(simul_pois2[, -c(1,2)])
 #' cID <- simul_pois2$cID
 #' 
-#' # BVS for a Poisson model with random intercept
-#' m3 <- poissonBvs(y = y, X = X, model = list(ri = TRUE, clusterID = cID),
+#' # BVS for a Poisson model with cluster-specific random intercept
+#' m4 <- poissonBvs(y = y, X = X, model = list(ri = TRUE, clusterID = cID),
 #'                  mcmc = list(M = 4000, burnin = 2000))
-#' print(m3)
-#' summary(m3)
-#' plot(m3)
-#' 
-#' # similar to m3, but without variance selection of the random intercept term
-#' model <- list(gammafix = 1, ri = 1, clusterID = cID)
-#' m4 <- poissonBvs(y = y, X = X, model = model, mcmc = list(M = 4000, thin = 5))
-#' print(m4)       
-#' summary(m4)          
+#' print(m4)
+#' summary(m4)
 #' plot(m4)
+#'                                
+#' # similar to m4, but without variance selection of the random intercept term
+#' model <- list(gammafix = 1, ri = 1, clusterID = cID)
+#' m5 <- poissonBvs(y = y, X = X, model = model, mcmc = list(M = 4000, thin = 5))
+#' print(m5)       
+#' summary(m5)          
+#' plot(m5)
 #' 
 #' # MCMC sampling without BVS for clustered observations
-#' m5 <- poissonBvs(y = y, X = X, model = list(ri = 1, clusterID = cID), 
+#' m6 <- poissonBvs(y = y, X = X, model = list(ri = 1, clusterID = cID), 
 #'                  BVS = FALSE)
-#' print(m5)         
-#' summary(m5)        
-#' plot(m5, maxPlots = 4)
+#' print(m6)         
+#' summary(m6)        
+#' plot(m6, maxPlots = 4)
 #' }
 
 poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
@@ -256,7 +280,6 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   model$ri       <- as.integer(model$ri)
   model$d        <- d 
   model$family   <- "poisson"
-  model$Zl       <- seq_len(n) 
   
   if (model$d > 0){
     if (length(model$deltafix) != model$d || !all(model$deltafix %in% c(0, 1))){
@@ -271,7 +294,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   if (length(model$gammafix) > 1 || !(model$gammafix %in% c(0, 1)) || !(model$ri %in% c(0, 1)))
     stop("invalid specification of random intercept selection")
   
-  if (model$ri==1){
+  if (model$ri == 1){
     if (!is.vector(model$clusterID)){
       stop("you must specify a cluster ID for random intercept selection")
     }
@@ -293,6 +316,16 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     btilde <- H <- NULL       
   }
   
+  # specify function call for mcmc
+  fun_select <- "select_poisson"
+  txt_fun <- "Poisson"
+  if (model$ri == 1){
+    if (nC == length(y)){
+      fun_select <- "select_poissonOD"
+      txt_fun <- "overdispersed Poisson"
+    }
+  }
+  
   df   <- d + 1 
   deff <- d + model$ri
   dall <- deff + 1
@@ -311,7 +344,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   )
   
   prior <- modifyList(defaultPrior, as.list(prior))
-  if (!all(prior$aj0==0)){
+  if (!all(prior$aj0 == 0)){
     prior$slab <- "Normal"
     if (BVS){
       warning(simpleWarning(paste(strwrap(paste("BVS is not performed if prior
@@ -324,7 +357,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     }
   }
   
-  if (prior$slab=="Normal"){
+  if (prior$slab == "Normal"){
     prior$psi.Q  <- prior$V
     prior$psi.nu <- NULL      
   } else {
@@ -344,10 +377,10 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
        )
   )
   
-  if (prior$slab=="Student") with(prior, stopifnot(psi.nu > 0))
+  if (prior$slab == "Student") with(prior, stopifnot(psi.nu > 0))
   if (length(prior$aj0) != deff)
     stop("invalid specification of prior means for regression effects")
-  if (model$ri==1) prior$invB0 <- diag(nC)
+  if (model$ri == 1) prior$invB0 <- diag(nC)
   
   
   #### MCMC sampling options
@@ -372,7 +405,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   
   with(mcmc,
        stopifnot(all(c(M, burnin, startsel, thin, verbose) >= c(1, 0, 1, 1, 0)),
-                 typeof(msave)=="logical")
+                 typeof(msave) == "logical")
   )
   
   if (typeof(BVS) != "logical") stop("invalid 'BVS' argument")    
@@ -381,7 +414,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
                                 "'startsel' was set to ", mcmc$burnin/2, sep = "")))
     mcmc$startsel <- mcmc$burnin/2 
   }
-  if (BVS && sum(sum(model$deltafix) + sum(model$gammafix))==sum(model$d + model$ri)){
+  if (BVS && sum(sum(model$deltafix) + sum(model$gammafix)) == sum(model$d + model$ri)){
     warning(simpleWarning(paste("invalid 'BVS' argument:\n",
                                 "'BVS' was set to ", FALSE, sep = "")))
     BVS <- FALSE
@@ -412,7 +445,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   start$delta <- start$pdelta <- matrix(1, 1, model$d)
   start$psi   <- matrix(prior$V, 1, deff)  
   start$omega <- 1
-  if(model$ri==1){
+  if(model$ri == 1){
     start$gamma <- start$pgamma <- matrix(1, 1, model$ri)   
     start$theta <- rnorm(model$ri, 0, 0.1)
     start$pi    <- matrix(1, 1, model$ri)
@@ -432,7 +465,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     pgamma    = start$pgamma,
     pi        = start$pi)
   
-    
+  
   ## mixture components of Gaussian mixture approximation
   mcomp <- mixcomp_poisson()
   
@@ -468,7 +501,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     deltaBeta <- matrix(0, mcmc$nmc, model$d) 
     colnames(deltaBeta) <- paste("deltaB", seq_len(model$d), sep = ".")
   }
-  if (model$ri==1){
+  if (model$ri == 1){
     pgammaBeta <- thetaBeta <- matrix(0, mcmc$nmc, model$ri)
     colnames(pgammaBeta) <- "pgammaB"
     colnames(thetaBeta)  <- "thetaB"
@@ -483,24 +516,25 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     pgammaBeta <- thetaBeta <- bi <- piBeta <- gammaBeta <- NULL
   }
   
+
   
   #### ------------------------------ MCMC ------------------------------
   for (imc in 1:mcmc$nmc){
     
     if (mcmc$verbose > 0){
-      if (imc==1) cat(paste("\nMCMC for Poisson model", txt.verbose, ":\n\n", sep = ""))
+      if (imc == 1) cat(paste0("\nMCMC for the ", txt_fun, " model", txt.verbose, ":\n\n"))
       if (is.element(imc, c(1:5, 10, 20, 50, 100, 200, 500))){
         cat("it =", imc, "/--- duration of MCMC so far:", 
             round(timediff <- proc.time()[3] - starttime, 2), "sec.,  expected time to end:", 
             round((timediff/(imc - 1) * mcmc$nmc - timediff)/60, 2), " min. \n")
         flush.console()
-      } else if (imc %% mcmc$verbose==0 && imc < mcmc$nmc){
+      } else if (imc %% mcmc$verbose == 0 && imc < mcmc$nmc){
         cat("it =", imc, "/--- duration of MCMC so far:", 
             round(timediff <- proc.time()[3] - starttime, 2), "sec.,  expected time to end:", 
             round((timediff/(imc - 1) * mcmc$nmc - timediff)/60, 2), " min. \n")
         flush.console()
       }
-      else if (imc==mcmc$nmc) {
+      else if (imc == mcmc$nmc) {
         cat("it =", imc, "/--- duration of MCMC (total):", 
             round(timediff <- proc.time()[3] - starttime, 2), "sec. \n \n")
         flush.console() 
@@ -509,12 +543,16 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
     
     
     ## time since burn-in phase
-    if (imc==(mcmc$burnin + 1)) starttimeM <- proc.time()[3] 
+    if (imc == (mcmc$burnin + 1)) starttimeM <- proc.time()[3] 
     
     ## update 
-    par.pois <- select_poisson(y, X, offset, H, mcomp, compmix.pois, cm1, model,
-                            prior, mcmc, par.pois, imc)
-    
+    par.pois <- do.call(fun_select, args=list(y=y, X=X, offset=offset, H=H, 
+                                              mcomp=mcomp, 
+                                              compmix.pois = compmix.pois, 
+                                              cm1=cm1, model=model,
+                                              prior=prior, mcmc=mcmc,
+                                              param=par.pois, imc=imc)
+    )
     
     ## saving MCMC draws
     beta[imc,] <- par.pois$beta
@@ -528,7 +566,7 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
       deltaBeta[imc,] <- par.pois$delta
     }
     
-    if(model$ri==1){
+    if(model$ri == 1){
       pgammaBeta[imc] <- par.pois$pgamma
       thetaBeta[imc]  <- par.pois$theta
       bi[imc,]         <- t(par.pois$btilde*par.pois$theta)
@@ -557,12 +595,9 @@ poissonBvs <- function(y, offset = NULL, X, model = list(), mcmc  = list(),
   
   ret <- list(samplesP = samplesP, data = list(y = y, offset = offset, X = X), 
               model.pois = model, mcmc = mcmc, prior.pois = prior, dur = dur, 
-              BVS = BVS, start = start, family = model$family, call = cl) 
+              BVS = BVS, start = start, family = model$family, call = cl,
+              fun = fun_select) 
   class(ret) <- "pogit"
   return(ret)
 }
-    
-  
-  
-  
-  
\ No newline at end of file
+
